#include <iostream> // score: 100
#include <unordered_map>
#include <limits>
#include <vector>
#include <algorithm>
#include <tuple>
using u64 = std::size_t;

struct state {
  int pos, left, right;
};
bool operator==(state a, state b) {
  return std::tie(a.pos, a.left, a.right) == std::tie(b.pos, b.left, b.right);
}
namespace std {
template <> struct hash<state> {
  u64 operator()(state s) const {
    return s.left + 1000*s.right + 1000*1000*s.pos;
  }
};
}
struct value {
  value(u64 cost = std::numeric_limits<u64>::max(), u64 dvds = 0)
      : cost(cost), dvds(dvds) {}
  u64 cost, dvds;
};
bool operator<(value a, value b) { return a.cost < b.cost; }
std::unordered_map<state, value> memo;
std::vector<std::pair<int, int>> stores;
int middle;

value best(state s) {
  auto &res = memo[s];
  if (res.cost != std::numeric_limits<u64>::max())
    return res;
  int l = s.left == s.pos ? std::min(s.left + 1, middle) : s.left;
  int r = s.left == s.pos ? s.right : std::max(s.right - 1, middle);
  for (auto t : {state{l, l, r}, {r, l, r}}) {
    if (t == s)
      continue;
    auto v = best(t);
    v.cost += std::abs(stores[s.pos].first - stores[t.pos].first) * v.dvds;
    v.dvds -= stores[s.pos].second;
    res = std::min(v, res);
  }
  return res;
}

int main() {
  std::ios_base::sync_with_stdio(false);
  int n;
  std::cin >> n;
  stores.push_back({0, 0});
  u64 total_dvds = 0;
  for (int a, b; std::cin >> a >> b; total_dvds += b)
    stores.push_back({a, b});
  std::sort(stores.begin(), stores.end());
  middle = std::lower_bound(stores.begin(), stores.end(),
                            std::pair<int, int>{0, 0}) -
           stores.begin();
  memo[{middle, middle, middle}] = {0, total_dvds};
  std::cout << std::min(best({0, 0, n}), best({n, 0, n})).cost << '\n';
}
